@@ -26,6 +26,7 @@
 #include "cscmi.h"
 #include "draw.h"
 #include "events.h"
+#include "scroll-menu.h"
 
 static GtkWidget *about = NULL;
 
@@ -73,16 +74,23 @@ void help_about_callback ()
   const gchar *authors[] = {
 	  N_("Main program:  Jonathan Blandford (jrb@redhat.com)"),
 	  N_("                      Felix Bellaby (felix@pooh.u-net.com)"),
-	  N_("                      Rosanna Yuen (rwsy@mit.edu)"),
+	  N_("                      Rosanna Yuen (zana@webwynk.net)"),
 	  N_("Card Games:    Jonathan Blandford (jrb@redhat.com)"),
 	  N_("                      W. Borgert (debacle@debian.org)"),
 	  N_("                      Robert Brady (rwb197@ecs.soton.ac.uk)"),
 	  N_("                      Nick Lamb (njl195@zepler.org.uk)"),
 	  N_("                      Changwoo Ryu (cwryu@adam.kaist.ac.kr)"),
-	  N_("                      Rosanna Yuen (rwsy@mit.edu)"),
+          N_("                      Matthew Wilcox (matthew@wil.cx)"),
+	  N_("                      Rosanna Yuen (zana@webwynk.net)"),
 	  NULL
   };
 
+  const gchar *documenters[] = {
+	  NULL
+  };
+
+  const gchar *translator_credits = _("");
+
 #ifdef ENABLE_NLS
   {
 	int i=0;
@@ -97,10 +105,11 @@ void help_about_callback ()
   about = gnome_about_new ( _("AisleRiot"), VERSION,
 			    /* copyright notice */
 			    _("(C) 1998 Jonathan Blandford (jrb@redhat.com)"),
-			    (const char **)authors,
-			    /* another comments */
 			    _("AisleRiot provides a rule-based "
-			      "solitaire card engine that allows many different games to be played"),
+			    "solitaire card engine that allows many different games to be played"),
+			    (const char **)authors,
+			    (const char **)documenters,
+			    (const char *)translator_credits,
 			    NULL);
   gtk_signal_connect (GTK_OBJECT (about),
 		      "destroy",
@@ -132,11 +141,6 @@ GnomeUIInfo settings_menu[] = {
   GNOMEUIINFO_END
 };
 
-GnomeUIInfo rules_menu[] = {
-
-  GNOMEUIINFO_END
-};
-
 GnomeUIInfo help_menu[] = {
   GNOMEUIINFO_HELP("aisleriot"),
 
@@ -149,11 +153,8 @@ GnomeUIInfo game_menu[] = {
 
   GNOMEUIINFO_MENU_NEW_GAME_ITEM(random_seed, NULL),
 
-  { GNOME_APP_UI_SUBTREE, N_("New _game of..."),
-    N_("Start a new game of a different variation"),
-    rules_sub_menu, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
-    GNOME_STOCK_MENU_NEW, 0, 0, NULL },
-  
+  GNOMEUIINFO_ITEM (N_("New _game of..."), N_("Start a new game of a different variation"), NULL, NULL),
+
   GNOMEUIINFO_MENU_RESTART_GAME_ITEM(restart_game, NULL),
 
   GNOMEUIINFO_ITEM_STOCK(N_("_Select..."), N_("Select a new game variation"),
@@ -227,18 +228,29 @@ void create_menus ()
 {
   int i;
   GtkWidget *w;
+  GtkWidget *menu_item;
+  GtkWidget *menu;
   gnome_app_create_menus (GNOME_APP(app), top_menu);
   gnome_app_create_toolbar (GNOME_APP(app), toolbar);
 
+  /* Kids, don't try this at home */
+  menu_item = game_menu [1].widget;
+  menu = scroll_menu_new ();
+  gtk_menu_item_set_submenu (GTK_MENU_ITEM (menu_item), menu);
+  w = gtk_tearoff_menu_item_new ();
+  gtk_widget_show(w);
+  gtk_menu_shell_append (GTK_MENU_SHELL(menu), w);
+
   for(i = 0; i < n_games; i++) {
     w = gtk_menu_item_new_with_label 
       (game_file_to_name (game_dents[i]->d_name));
     gtk_widget_show(w);
-    gtk_menu_shell_append (GTK_MENU_SHELL(rules_sub_menu[0].widget), w);
+    gtk_menu_shell_append (GTK_MENU_SHELL(menu), w);
     gtk_signal_connect (GTK_OBJECT(w), "activate", 
 			(GtkSignalFunc) new_rules,
 			(gpointer) game_dents[i]->d_name);
   }
+  gtk_widget_show_all (menu);
 }
 
 void install_menu_hints (GnomeApp *app)
