@@ -25,6 +25,7 @@
 
 #include "ataxx.h"
 #include "gataxx.h"
+#include "clock.h"
 
 guint flip_final_id = 0;
 gint flip_final;
@@ -131,15 +132,19 @@ gint move_board(gint8 board[7][7], guint x, guint y, guint selected_x, guint sel
     if(whose_turn == WHITE_TURN) {
       whose_turn = BLACK_TURN;
       gui_message(_("Dark's move"));
+
       if(!white_computer_level) {
-	gtk_clock_stop(GTK_CLOCK(time_display));
+	clock_stop(CLOCK(time_display));
       }
+
     } else {
       whose_turn = WHITE_TURN;
       gui_message(_("Light's move"));
+
       if(!black_computer_level) {
-	gtk_clock_stop(GTK_CLOCK(time_display));
+	clock_stop(CLOCK(time_display));
       }
+
     }
     
     
@@ -187,14 +192,14 @@ gint move_board(gint8 board[7][7], guint x, guint y, guint selected_x, guint sel
     }
     
     gui_status();
-    
+   
     if(not_me == BLACK_TURN && !black_computer_level && timer_valid) {
-      gtk_clock_start(GTK_CLOCK(time_display));
+      clock_start(CLOCK(time_display));
     }
     if(not_me == WHITE_TURN && !white_computer_level && timer_valid) {
-      gtk_clock_start(GTK_CLOCK(time_display));
+      clock_start(CLOCK(time_display));
     }
-    
+   
     tiles_to_flip = 1;
   }
   
@@ -575,7 +580,7 @@ gint check_valid_moves()
   }
 
   if(!white_moves || !black_moves) {
-    gtk_clock_stop(GTK_CLOCK(time_display));
+    clock_stop(CLOCK(time_display));
     white_moves = count_pieces(board, WHITE_TURN);
     black_moves = count_pieces(board, BLACK_TURN);
     if(white_moves > black_moves)
@@ -596,9 +601,9 @@ gint check_valid_moves()
     whose_turn = BLACK_TURN;
     if(white_computer_level ^ black_computer_level) {
       if(!black_computer_level && timer_valid)
-	gtk_clock_start(GTK_CLOCK(time_display));
+	clock_start(CLOCK(time_display));
       else
-	gtk_clock_stop(GTK_CLOCK(time_display));
+	clock_stop(CLOCK(time_display));
     }
     return(TRUE);
   }
@@ -608,9 +613,9 @@ gint check_valid_moves()
     whose_turn = WHITE_TURN;
     if(white_computer_level ^ black_computer_level) {
       if(!white_computer_level && timer_valid)
-	gtk_clock_start(GTK_CLOCK(time_display));
+	clock_start(CLOCK(time_display));
       else
-	gtk_clock_stop(GTK_CLOCK(time_display));
+	clock_stop(CLOCK(time_display));
     }
     return(TRUE);
   }
