@@ -24,6 +24,7 @@
 #include <gnome.h>
 #include <libgnomeui/gnome-window-icon.h>
 #include <gdk/gdkkeysyms.h>
+#include <gdk-pixbuf/gdk-pixbuf.h>
 
 #include <sys/time.h>
 #include <string.h>
@@ -31,7 +32,7 @@
 #include "gataxx.h"
 #include "ataxx.h"
 #include "properties.h"
-
+#include "clock.h"
 
 GdkPixmap *buffer_pixmap = NULL;
 GdkPixmap *tiles_pixmap = NULL;
@@ -219,65 +220,67 @@ GnomeUIInfo mainmenu[] = {
 	GNOMEUIINFO_END
 };
 
-void quit_game_maybe(GtkWidget *widget, gint button)
+gboolean quit_game_cb(GtkWidget *widget, gpointer data)
 {
-	if(button == 0) {
-		if (flip_pixmaps_id)
-			gtk_timeout_remove(flip_pixmaps_id);
-		if (black_computer_id)
-			gtk_timeout_remove(black_computer_id);
-		if (white_computer_id)
-			gtk_timeout_remove(white_computer_id);
+  if(game_in_progress) {
+    GtkWidget *box;
+    gint response;
 
-		if(buffer_pixmap)
-			gdk_pixmap_unref(buffer_pixmap);
-		if(tiles_pixmap)
-			gdk_pixmap_unref(tiles_pixmap);
-		if(tiles_mask)
-			gdk_pixmap_unref(tiles_mask);
+    box = gtk_message_dialog_new (GTK_WINDOW (window),
+                                 GTK_DIALOG_DESTROY_WITH_PARENT,
+                                 GTK_MESSAGE_QUESTION,
+                                 GTK_BUTTONS_YES_NO,
+                                 _("Do you really want to quit?"));
+    gtk_dialog_set_default_response (GTK_DIALOG (box), GTK_RESPONSE_YES);
 
-		gtk_main_quit();
-	}
-}
+    response = gtk_dialog_run (GTK_DIALOG (box));
+    gtk_widget_destroy (box);
 
-void quit_game_cb(GtkWidget *widget, gpointer data)
-{
-	GtkWidget *box;
-
-	if(game_in_progress) {
-		box = gnome_message_box_new(_("Do you really want to quit?"), GNOME_MESSAGE_BOX_QUESTION, GNOME_STOCK_BUTTON_YES, GNOME_STOCK_BUTTON_NO, NULL);
-		gnome_dialog_set_parent(GNOME_DIALOG(box), GTK_WINDOW(window));
-		gnome_dialog_set_default(GNOME_DIALOG(box), 0);
-		gtk_window_set_modal(GTK_WINDOW(box), TRUE);
-		gtk_signal_connect(GTK_OBJECT(box), "clicked", (GtkSignalFunc)quit_game_maybe, NULL);
-		gtk_widget_show(box);
-	} else {
-		quit_game_maybe(NULL, 0);
-	}
-}
-
-void new_game_maybe(GtkWidget *widget, int button)
-{
-  if (button == 0) {
-    /*network_new(); */
-    init_new_game();
+    if (response == GTK_RESPONSE_NO)
+      return TRUE;
   }
+
+  if (flip_pixmaps_id)
+    gtk_timeout_remove(flip_pixmaps_id);
+  if (black_computer_id)
+    gtk_timeout_remove(black_computer_id);
+  if (white_computer_id)
+    gtk_timeout_remove(white_computer_id);
+
+  if(buffer_pixmap)
+    gdk_drawable_unref(buffer_pixmap);
+  if(tiles_pixmap)
+    gdk_drawable_unref(tiles_pixmap);
+  if(tiles_mask)
+    gdk_drawable_unref(tiles_mask);
+
+  gtk_main_quit();
+
+  return FALSE;
 }
 
 void new_game_cb(GtkWidget *widget, gpointer data) {
-  GtkWidget *box;
   
   if(game_in_progress) {
-    box = gnome_message_box_new(_("Do you really want to end this game?"), GNOME_MESSAGE_BOX_QUESTION, GNOME_STOCK_BUTTON_YES, GNOME_STOCK_BUTTON_NO, NULL);
-    gnome_dialog_set_parent(GNOME_DIALOG(box), GTK_WINDOW(window));
-    gnome_dialog_set_default(GNOME_DIALOG(box), 0);
-    gtk_window_set_modal(GTK_WINDOW(box), TRUE);
-    gtk_signal_connect(GTK_OBJECT(box), "clicked", (GtkSignalFunc)new_game_maybe, NULL);
-    gtk_widget_show(box);
-  } else {
-    /*network_new(); */
-    init_new_game();
+    GtkWidget *box;
+    gint response;
+
+    box = gtk_message_dialog_new (GTK_WINDOW (window),
+                                 GTK_DIALOG_DESTROY_WITH_PARENT,
+                                 GTK_MESSAGE_QUESTION,
+                                 GTK_BUTTONS_YES_NO,
+                                 _("Do you really want to end this game?"));
+    gtk_dialog_set_default_response (GTK_DIALOG (box), GTK_RESPONSE_YES);
+
+    response = gtk_dialog_run (GTK_DIALOG (box));
+    gtk_widget_destroy (box);
+
+    if (response == GTK_RESPONSE_NO)
+      return;
+
   }
+  /*network_new(); */
+  init_new_game();
 }
 
 void undo_move_cb(GtkWidget *widget, gpointer data) {
@@ -334,9 +337,9 @@ void undo_move_cb(GtkWidget *widget, gpointer data) {
   gui_status();
   
   if(timer_valid) {
-    gtk_clock_stop(GTK_CLOCK(time_display));
+    clock_stop(CLOCK(time_display));
     gtk_widget_set_sensitive(time_display, FALSE);
-    gtk_clock_set_seconds(GTK_CLOCK(time_display), 0);
+    clock_set_seconds(CLOCK(time_display), 0);
     timer_valid = 0;
   }
   
@@ -356,9 +359,9 @@ void black_level_cb(GtkWidget *widget, gpointer data) {
   black_computer_level = tmp;
   
   if(game_in_progress) {
-    gtk_clock_stop(GTK_CLOCK(time_display));
+    clock_stop(CLOCK(time_display));
     gtk_widget_set_sensitive(time_display, FALSE);
-    gtk_clock_set_seconds(GTK_CLOCK(time_display), 0);
+    clock_set_seconds(CLOCK(time_display), 0);
     timer_valid = 0;
   }
   
@@ -377,9 +380,9 @@ void white_level_cb(GtkWidget *widget, gpointer data)
   white_computer_level = tmp;
   
   if(game_in_progress) {
-    gtk_clock_stop(GTK_CLOCK(time_display));
+    clock_stop(CLOCK(time_display));
     gtk_widget_set_sensitive(time_display, FALSE);
-    gtk_clock_set_seconds(GTK_CLOCK(time_display), 0);
+    clock_set_seconds(CLOCK(time_display), 0);
     timer_valid = 0;
   }
   
@@ -391,6 +394,11 @@ void about_cb(GtkWidget *widget, gpointer data) {
   static GtkWidget *about;
   
   const gchar *authors[] = {"Chris Rogers", NULL};
+  gchar *documenters[] = {
+                          NULL
+                          };
+  /* Translator credits */
+  gchar *translator_credits = _("");
   
   if (about != NULL) {
     gdk_window_raise (about->window);
@@ -398,11 +406,15 @@ void about_cb(GtkWidget *widget, gpointer data) {
     return;
   }
   
-  about = gnome_about_new(_("gataxx"), VERSION, "(C) 1999 Chris Rogers", (const char **)authors,
-			  _("gataxx is a Gnome port of the old game ataxx.  It is derived from Ian Peters' iagno code."), NULL);
-  gtk_signal_connect (GTK_OBJECT (about), "destroy", GTK_SIGNAL_FUNC
+  about = gnome_about_new(_("gataxx"), VERSION, "(C) 1999 Chris Rogers",
+  			  _("gataxx is a Gnome port of the old game ataxx.  It is derived from Ian Peters' iagno code."),
+  			  (const char **)authors,
+  			  (const char **)documenters,
+                          (const char *)translator_credits,
+			  NULL);
+  g_signal_connect (G_OBJECT (about), "destroy", G_CALLBACK
 		      (gtk_widget_destroyed), &about);
-  gnome_dialog_set_parent(GNOME_DIALOG(about), GTK_WINDOW(window));
+  gtk_window_set_transient_for (GTK_WINDOW (about), GTK_WINDOW(window));
   
   gtk_widget_show(about);
 }
@@ -415,7 +427,7 @@ gint expose_event(GtkWidget *widget, GdkEventExpose *event){
 
   int i;
 
-  gdk_draw_pixmap(widget->window, widget->style->fg_gc[GTK_WIDGET_STATE(widget)], buffer_pixmap, event->area.x, event->area.y, event->area.x, event->area.y, event->area.width, event->area.height);
+  gdk_draw_drawable(widget->window, widget->style->fg_gc[GTK_WIDGET_STATE(widget)], buffer_pixmap, event->area.x, event->area.y, event->area.x, event->area.y, event->area.width, event->area.height);
   
  
  for(i = 0; i < 7; i++) {
@@ -431,7 +443,7 @@ gint configure_event(GtkWidget *widget, GdkEventConfigure *event) {
   guint i, j;
   
   if(buffer_pixmap)
-    gdk_pixmap_unref(buffer_pixmap);
+    gdk_drawable_unref(buffer_pixmap);
   buffer_pixmap = gdk_pixmap_new(widget->window, widget->allocation.width, widget->allocation.height, -1);
   
   for(i = 0; i < 7; i++)
@@ -504,8 +516,8 @@ void gui_draw_selected(gint x, gint y, gint on) {
 
 void gui_draw_pixmap(gint which, gint x, gint y) {
 
- gdk_draw_pixmap(drawing_area->window, drawing_area->style->fg_gc[GTK_WIDGET_STATE(drawing_area)], tiles_pixmap, (which % 7) * TILEWIDTH, (which / 7) * TILEHEIGHT, x * TILEWIDTH, y * TILEHEIGHT, TILEWIDTH, TILEHEIGHT);
-  gdk_draw_pixmap(buffer_pixmap, drawing_area->style->fg_gc[GTK_WIDGET_STATE(drawing_area)], tiles_pixmap, (which % 7) * TILEWIDTH, (which / 7) * TILEHEIGHT, x * TILEWIDTH, y * TILEHEIGHT, TILEWIDTH, TILEHEIGHT);
+ gdk_draw_drawable(drawing_area->window, drawing_area->style->fg_gc[GTK_WIDGET_STATE(drawing_area)], tiles_pixmap, (which % 7) * TILEWIDTH, (which / 7) * TILEHEIGHT, x * TILEWIDTH, y * TILEHEIGHT, TILEWIDTH, TILEHEIGHT);
+  gdk_draw_drawable(buffer_pixmap, drawing_area->style->fg_gc[GTK_WIDGET_STATE(drawing_area)], tiles_pixmap, (which % 7) * TILEWIDTH, (which / 7) * TILEHEIGHT, x * TILEWIDTH, y * TILEHEIGHT, TILEWIDTH, TILEHEIGHT);
   
 
   gdk_draw_line(drawing_area->window, window->style->black_gc, x * TILEWIDTH, y * TILEHEIGHT, (x) * TILEWIDTH, (y+1) * TILEHEIGHT);
@@ -517,35 +529,28 @@ void gui_draw_pixmap(gint which, gint x, gint y) {
 }
 void gui_draw_pixmap_buffer(gint which, gint x, gint y) {
 
-   gdk_draw_pixmap(buffer_pixmap, drawing_area->style->fg_gc[GTK_WIDGET_STATE(drawing_area)], tiles_pixmap, (which % 7) * TILEWIDTH, (which / 7) * TILEHEIGHT, x * TILEWIDTH, y * TILEHEIGHT, TILEWIDTH, TILEHEIGHT);
+   gdk_draw_drawable(buffer_pixmap, drawing_area->style->fg_gc[GTK_WIDGET_STATE(drawing_area)], tiles_pixmap, (which % 7) * TILEWIDTH, (which / 7) * TILEHEIGHT, x * TILEWIDTH, y * TILEHEIGHT, TILEWIDTH, TILEHEIGHT);
    
 }
 
 void load_pixmaps() {
   char *tmp;
   char *fname;
-  GdkImlibImage *image;
-  GdkVisual *visual;
+  GdkPixbuf *image;
   
   tmp = g_strconcat("gataxx/", tile_set, NULL);
-  fname = gnome_unconditional_pixmap_file(tmp);
+  fname = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, (tmp), FALSE, NULL);
   g_free(tmp);
   
-  if(!g_file_exists(fname)) {
+  if(!g_file_test (fname, G_FILE_TEST_EXISTS)) {
     g_print(_("Could not find \'%s\' pixmap file for gataxx\n"), fname);
     exit(1);
   }
   
-  image = gdk_imlib_load_image(fname);
-  visual = gdk_imlib_get_visual();
-  if(visual->type != GDK_VISUAL_TRUE_COLOR) {
-    gdk_imlib_set_render_type(RT_PLAIN_PALETTE);
-  }
-  gdk_imlib_render(image, image->rgb_width, image->rgb_height);
-  tiles_pixmap = gdk_imlib_move_image(image);
-  tiles_mask = gdk_imlib_move_mask(image);
+  image = gdk_pixbuf_new_from_file(fname, NULL);
+  gdk_pixbuf_render_pixmap_and_mask (image, &tiles_pixmap, &tiles_mask, 127);
   
-  gdk_imlib_destroy_image(image);
+  gdk_pixbuf_unref(image);
   g_free(fname);
 }
 
@@ -653,7 +658,7 @@ void init_new_game() {
     for(j = 0; j < 7; j++)
       gui_draw_pixmap_buffer(pixmaps[i][j], i, j);
   
-  gdk_draw_pixmap(drawing_area->window, drawing_area->style->fg_gc[GTK_WIDGET_STATE(drawing_area)], buffer_pixmap, 0, 0, 0, 0, BOARDWIDTH, BOARDHEIGHT);
+  gdk_draw_drawable(drawing_area->window, drawing_area->style->fg_gc[GTK_WIDGET_STATE(drawing_area)], buffer_pixmap, 0, 0, 0, 0, BOARDWIDTH, BOARDHEIGHT);
   for(i = 0; i < 7; i++) {
     gdk_draw_line(drawing_area->window, drawing_area->style->black_gc, i * TILEWIDTH, 0, i * TILEWIDTH, 7 * TILEHEIGHT);
     gdk_draw_line(drawing_area->window, drawing_area->style->black_gc, 0, (i * TILEHEIGHT) , 7 * TILEWIDTH, (i * TILEHEIGHT));
@@ -662,19 +667,19 @@ void init_new_game() {
   whose_turn = BLACK_TURN;
   gui_message(_("Dark's move"));
   
-  gtk_clock_stop(GTK_CLOCK(time_display));
-  gtk_clock_set_seconds(GTK_CLOCK(time_display), 0);
+  clock_stop(CLOCK(time_display));
+  clock_set_seconds(CLOCK(time_display), 0);
   
   if(black_computer_level ^ white_computer_level) {
     if(!black_computer_level)
-      gtk_clock_start(GTK_CLOCK(time_display));
+      clock_start(CLOCK(time_display));
     gtk_widget_set_sensitive(time_display, TRUE);
     timer_valid = 1;
   } else {
     gtk_widget_set_sensitive(time_display, FALSE);
     timer_valid = 0;
   }
-  
+ 
   check_computer_players();
 }
 
@@ -683,28 +688,22 @@ void create_window() {
   GtkWidget *table;
   GtkWidget *sep;
   
-  gtk_widget_push_visual (gdk_imlib_get_visual ());
-  gtk_widget_push_colormap (gdk_imlib_get_colormap ());
-
   window = gnome_app_new("gataxx", _("gataxx"));
   
   gtk_widget_realize(window);
   gtk_window_set_policy(GTK_WINDOW(window), FALSE, FALSE, TRUE);
-  gtk_signal_connect(GTK_OBJECT(window), "delete_event", GTK_SIGNAL_FUNC(quit_game_cb), NULL);
+  g_signal_connect(G_OBJECT(window), "delete_event", G_CALLBACK(quit_game_cb), NULL);
   
   gnome_app_create_menus(GNOME_APP(window), mainmenu);
   
   drawing_area = gtk_drawing_area_new();
 
-  gtk_widget_pop_colormap ();
-  gtk_widget_pop_visual ();
-  
   gnome_app_set_contents(GNOME_APP(window), drawing_area);
 
   gtk_drawing_area_size(GTK_DRAWING_AREA(drawing_area), BOARDWIDTH, BOARDHEIGHT);
-  gtk_signal_connect(GTK_OBJECT(drawing_area), "expose_event", GTK_SIGNAL_FUNC(expose_event), NULL);
-  gtk_signal_connect(GTK_OBJECT(drawing_area), "configure_event", GTK_SIGNAL_FUNC(configure_event), NULL);
-  gtk_signal_connect(GTK_OBJECT(drawing_area), "button_press_event", GTK_SIGNAL_FUNC(button_press_event), NULL);
+  g_signal_connect(G_OBJECT(drawing_area), "expose_event", G_CALLBACK(expose_event), NULL);
+  g_signal_connect(G_OBJECT(drawing_area), "configure_event", G_CALLBACK(configure_event), NULL);
+  g_signal_connect(G_OBJECT(drawing_area), "button_press_event", G_CALLBACK(button_press_event), NULL);
   gtk_widget_set_events(drawing_area, GDK_EXPOSURE_MASK | GDK_BUTTON_PRESS_MASK);
   gtk_widget_show(drawing_area);
 
@@ -743,13 +742,13 @@ void create_window() {
   gtk_widget_show(sep);
   
   gtk_table_attach(GTK_TABLE(table), sep, 6, 7, 0, 1, 0, GTK_FILL, 3, 3);
-  
-  time_display = gtk_clock_new(GTK_CLOCK_INCREASING);
+
+  time_display = clock_new();
   gtk_widget_set_sensitive(time_display, FALSE);
   gtk_widget_show(time_display);
   
   gtk_table_attach(GTK_TABLE(table), time_display, 7, 8, 0, 1, 0, 0, 3, 1);
-  
+
   gtk_widget_show(table);
   
   gtk_box_pack_start(GTK_BOX(appbar), table, FALSE, TRUE, 0);
@@ -762,9 +761,9 @@ void gui_status() {
   gchar message[3];
   
   sprintf(message, _("%.2d"), bcount);
-  gtk_label_set(GTK_LABEL(black_score), message);
+  gtk_label_set_text(GTK_LABEL(black_score), message);
   sprintf(message, _("%.2d"), wcount);
-  gtk_label_set(GTK_LABEL(white_score), message);
+  gtk_label_set_text(GTK_LABEL(white_score), message);
 }
 
 void gui_message(gchar *message) {
@@ -809,10 +808,10 @@ void set_bg_color() {
   GdkImage *tmpimage;
   GdkColor bgcolor;
   
-  tmpimage = gdk_image_get(tiles_pixmap, 0, 0, 1, 1);
+  tmpimage = gdk_drawable_get_image (tiles_pixmap, 0, 0, 1, 1);
   bgcolor.pixel = gdk_image_get_pixel(tmpimage, 0, 0);
   gdk_window_set_background(drawing_area->window, &bgcolor);
-  gdk_image_destroy(tmpimage);
+  gdk_image_unref(tmpimage);
 }
 
 static char *nstr(int n) {
@@ -855,8 +854,9 @@ int main(int argc, char **argv) {
     
     gnome_score_init("gataxx");
 
-    bindtextdomain(PACKAGE, GNOMELOCALEDIR);
-    textdomain(PACKAGE);
+    bindtextdomain(GETTEXT_PACKAGE, GNOMELOCALEDIR);
+    bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+    textdomain(GETTEXT_PACKAGE);
     
     gettimeofday(&tv, NULL);
     srand(tv.tv_usec);
@@ -871,13 +871,8 @@ int main(int argc, char **argv) {
     gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gataxx.png");
     client= gnome_master_client();
     
-    gtk_signal_connect(GTK_OBJECT(client), "save_yourself", GTK_SIGNAL_FUNC(save_state), argv[0]);
-    gtk_signal_connect(GTK_OBJECT(client), "die", GTK_SIGNAL_FUNC(quit_game_cb), argv[0]);
-    
-    /*
-    gtk_widget_push_visual (gdk_imlib_get_visual ());
-    gtk_widget_push_colormap (gdk_imlib_get_colormap ());
-    */
+    g_signal_connect(G_OBJECT(client), "save_yourself", G_CALLBACK(save_state), argv[0]);
+    g_signal_connect(G_OBJECT(client), "die", G_CALLBACK(quit_game_cb), argv[0]);
   
     create_window();
     
