@@ -27,6 +27,7 @@
 #include "properties.h"
 #include "gataxx.h"
 #include "ataxx.h"
+#include "clock.h"
 
 static GtkWidget *propbox = NULL;
 
@@ -50,6 +51,7 @@ guint t_white_computer_level;
 gint t_animate;
 gint t_quick_moves;
 gint t_flip_final;
+gint response;
 
 int mapped = 0;
 
@@ -62,24 +64,23 @@ void load_properties ()
 	strncpy (tile_set, gnome_config_get_string
 			("/gataxx/Preferences/tileset=classic.png"), 255);
 	animate = gnome_config_get_int ("/gataxx/Preferences/animate=2");
-	if (gnome_config_get_int ("/gataxx/Preferences/quickmoves=0"))
+	if (gnome_config_get_int ("/gataxx/Preferences/quickmoves=0")) {
 		computer_speed = COMPUTER_MOVE_DELAY / 2;
-	else
+	}
+	else {
 		computer_speed = COMPUTER_MOVE_DELAY;
+	}
 	flip_final = gnome_config_get_int
 		("/gataxx/Preferences/flipfinal=1");
 	
 	switch (animate) {
 		case 0:
-			flip_pixmaps_id = gtk_timeout_add (100, flip_pixmaps,
-					NULL);
+			flip_pixmaps_id = gtk_timeout_add (100, flip_pixmaps, NULL);
 			break;
 		case 1:
-			flip_pixmaps_id = gtk_timeout_add (PIXMAP_FLIP_DELAY *
-					8, flip_pixmaps, NULL);
+			flip_pixmaps_id = gtk_timeout_add (PIXMAP_FLIP_DELAY * 8, flip_pixmaps, NULL);
 			break;
-		case 2: flip_pixmaps_id = gtk_timeout_add (PIXMAP_FLIP_DELAY,
-					flip_pixmaps, NULL);
+		case 2: flip_pixmaps_id = gtk_timeout_add (PIXMAP_FLIP_DELAY, flip_pixmaps, NULL);
 			break;
 	}
 }
@@ -97,55 +98,20 @@ void reset_properties ()
 	t_flip_final = flip_final;
 }
 
-void black_computer_level_select (GtkWidget *widget, gpointer data)
+void save_properties ()
 {
-	if (((guint) data != t_black_computer_level) &&
-		       (GTK_TOGGLE_BUTTON (widget)->active)) {
-		t_black_computer_level = (guint) data;
-		if (mapped)
-			gnome_property_box_changed (GNOME_PROPERTY_BOX
-					(propbox));
-	}
-}
-
-void white_computer_level_select (GtkWidget *widget, gpointer data)
-{
-	if (((guint) data != t_white_computer_level) &&
-		       (GTK_TOGGLE_BUTTON (widget)->active)) {
-		t_white_computer_level = (guint) data;
-		if (mapped)
-			gnome_property_box_changed (GNOME_PROPERTY_BOX
-					(propbox));
-	}
-}
-
-void quick_moves_select (GtkWidget *widget, gpointer data)
-{
-	if (GTK_TOGGLE_BUTTON (widget)->active)
-		t_quick_moves = 1;
-	else
-		t_quick_moves = 0;
-
-	gnome_property_box_changed (GNOME_PROPERTY_BOX (propbox));
-}
-
-void flip_final_select (GtkWidget *widget, gpointer data)
-{
-	if (GTK_TOGGLE_BUTTON (widget)->active)
-		t_flip_final = 1;
-	else
-		t_flip_final = 0;
-
-	gnome_property_box_changed (GNOME_PROPERTY_BOX (propbox));
-}
-
-
-void animate_select (GtkWidget *widget, gpointer data)
-{
-	if (GTK_TOGGLE_BUTTON (widget)->active) {
-		t_animate = (gint) data;
-		gnome_property_box_changed (GNOME_PROPERTY_BOX (propbox));
-	}
+	gnome_config_set_int ("/gataxx/Preferences/blacklevel",
+			black_computer_level);
+	gnome_config_set_int ("/gataxx/Preferences/whitelevel",
+			white_computer_level);
+	gnome_config_set_int ("/gataxx/Preferences/quickmoves",
+			t_quick_moves);
+	gnome_config_set_string ("/gataxx/Preferences/tileset",
+			tile_set_tmp);
+	gnome_config_set_int ("/gataxx/Preferences/animate", animate);
+	gnome_config_set_int ("/gataxx/Preferences/flipfinal", flip_final);
+	
+	gnome_config_sync ();
 }
 
 void apply_changes ()
@@ -154,9 +120,9 @@ void apply_changes ()
 	
 	if ((black_computer_level != t_black_computer_level) ||
 			(white_computer_level != t_white_computer_level)) {
-		gtk_clock_stop (GTK_CLOCK (time_display));
+		clock_stop (CLOCK (time_display));
 		gtk_widget_set_sensitive (time_display, FALSE);
-		gtk_clock_set_seconds (GTK_CLOCK (time_display), 0);
+		clock_set_seconds (CLOCK (time_display), 0);
 		timer_valid = 0;
 	}
 
@@ -173,10 +139,12 @@ void apply_changes ()
 		white_computer_id = 0;
 	}
 	
-	if (t_quick_moves)
+	if (t_quick_moves) {
 		computer_speed = COMPUTER_MOVE_DELAY / 2;
-	else
+	}
+	else {
 		computer_speed = COMPUTER_MOVE_DELAY;
+	}
 	
 	if (strcmp (tile_set, tile_set_tmp)) {
 		strncpy (tile_set, tile_set_tmp, 255);
@@ -184,10 +152,12 @@ void apply_changes ()
 		for (i = 0; i < 7; i++)
 			for (j = 0; j < 7; j++)
 				if (pixmaps [i][j] >= BLACK_TURN &&
-						pixmaps[i][j] <= WHITE_TURN)
+						pixmaps[i][j] <= WHITE_TURN) {
 					gui_draw_pixmap (pixmaps[i][j], i, j);
-				else
+				}
+				else {
 					gui_draw_pixmap (0, i, j);
+				}
 	}
 	
 	animate = t_animate;
@@ -215,29 +185,62 @@ void apply_changes ()
 	flip_final = t_flip_final;
 	
 	check_computer_players ();
+	save_properties ();
 }
 
-void save_properties ()
+void black_computer_level_select (GtkWidget *widget, gpointer data)
 {
-	gnome_config_set_int ("/gataxx/Preferences/blacklevel",
-			black_computer_level);
-	gnome_config_set_int ("/gataxx/Preferences/whitelevel",
-			white_computer_level);
-	gnome_config_set_int ("/gataxx/Preferences/quickmoves",
-			t_quick_moves);
-	gnome_config_set_string ("/gataxx/Preferences/tileset",
-			tile_set_tmp);
-	gnome_config_set_int ("/gataxx/Preferences/animate", animate);
-	gnome_config_set_int ("/gataxx/Preferences/flipfinal", flip_final);
-	
-	gnome_config_sync ();
+	if (((guint) data != t_black_computer_level) &&
+		       (GTK_TOGGLE_BUTTON (widget)->active)) {
+		t_black_computer_level = (guint) data;
+	}
+	apply_changes ();
+}
+
+void white_computer_level_select (GtkWidget *widget, gpointer data)
+{
+	if (((guint) data != t_white_computer_level) &&
+		       (GTK_TOGGLE_BUTTON (widget)->active)) {
+		t_white_computer_level = (guint) data;
+	}
+	apply_changes ();
+}
+
+void quick_moves_select (GtkWidget *widget, gpointer data)
+{
+	if (GTK_TOGGLE_BUTTON (widget)->active) {
+		t_quick_moves = 1;
+	}
+	else {
+		t_quick_moves = 0;
+	}
+
+	apply_changes ();
+}
+
+void flip_final_select (GtkWidget *widget, gpointer data)
+{
+	if (GTK_TOGGLE_BUTTON (widget)->active) {
+		t_flip_final = 1;
+	}
+	else {
+		t_flip_final = 0;
+	}
+	apply_changes ();
+}
+
+
+void animate_select (GtkWidget *widget, gpointer data)
+{
+	if (GTK_TOGGLE_BUTTON (widget)->active) {
+		t_animate = (gint) data;
+	}
+	apply_changes ();
 }
 
 void apply_cb (GtkWidget *widget, gpointer data)
 {
 	apply_changes();
-	
-	save_properties ();
 }
 
 void destroy_cb (GtkWidget *widget, gpointer data)
@@ -248,7 +251,6 @@ void destroy_cb (GtkWidget *widget, gpointer data)
 void set_selection(GtkWidget *widget, gpointer data)
 {
 	if (strcmp ((gchar *)data, tile_set_tmp)) {
-		gnome_property_box_changed (GNOME_PROPERTY_BOX (propbox));
 	        strncpy(tile_set_tmp, data, 255);
 	}
 }
@@ -261,18 +263,19 @@ void free_str(GtkWidget *widget, void *data)
 void fill_menu(GtkWidget *menu)
 {
         struct dirent *e;
-        char *dname = gnome_unconditional_pixmap_file("gataxx");
+	char *dname = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, ("gataxx"), FALSE, NULL);
         DIR *dir;
         int itemno = 0;
 
         dir = opendir(dname);
 
-        if(!dir)
+        if(!dir) {
                 return;
+	}
 
         while((e = readdir(dir)) != NULL) {
                 GtkWidget *item;
-                char *s = strdup(e->d_name);
+                char *s = GINT_TO_POINTER (g_strdup(e->d_name));
                 if(!strstr(e->d_name, ".png")) {
                         free(s);
                         continue;
@@ -280,11 +283,11 @@ void fill_menu(GtkWidget *menu)
 
                 item = gtk_menu_item_new_with_label(s);
                 gtk_widget_show(item);
-                gtk_menu_append(GTK_MENU(menu), item);
-                gtk_signal_connect(GTK_OBJECT(item), "activate",
-				(GtkSignalFunc)set_selection, s);
-                gtk_signal_connect(GTK_OBJECT(item), "destroy",
-				(GtkSignalFunc)free_str, s);
+                gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
+                g_signal_connect(G_OBJECT(item), "activate",
+				 G_CALLBACK (set_selection), s);
+                g_signal_connect(G_OBJECT(item), "destroy",
+				 G_CALLBACK (free_str), s);
 
                 if (!strcmp(tile_set, s)) {
                         gtk_menu_set_active(GTK_MENU(menu), itemno);
@@ -297,209 +300,223 @@ void fill_menu(GtkWidget *menu)
 
 void show_properties_dialog ()
 {
-	GtkWidget *hbox;
+	GtkWidget *notebook;
+	GtkWidget *propbox;
+	GtkWidget *frame;
 	GtkWidget *label;
 	GtkWidget *label2;
 	GtkWidget *table;
 	GtkWidget *button;
-	GtkWidget *frame;
-	GtkWidget *vbox;
-	GtkWidget *option_menu;
 	GtkWidget *menu;
+	GtkWidget *vbox;
+	GtkWidget *hbox;
+	GtkWidget *option_menu;
 	
-	if (propbox)
-		return;
+	propbox = gtk_dialog_new_with_buttons (_("Properties"),
+					       GTK_WINDOW (window),
+					       GTK_DIALOG_DESTROY_WITH_PARENT | GTK_DIALOG_NO_SEPARATOR,
+					       _("Done"),
+					       GTK_RESPONSE_OK,
+					       NULL);
 	
-	reset_properties ();
+	g_signal_connect (G_OBJECT (propbox), "response",
+			  G_CALLBACK (gtk_widget_destroy), propbox);
+
+	g_signal_connect (G_OBJECT (propbox), "delete_event",
+			  G_CALLBACK (gtk_widget_destroy), propbox);
 	
-	propbox = gnome_property_box_new ();
-	gnome_dialog_set_parent (GNOME_DIALOG (propbox), GTK_WINDOW (window));
-	gtk_signal_connect (GTK_OBJECT (propbox), "destroy", GTK_SIGNAL_FUNC
-			(gtk_widget_destroyed), &propbox);
+	vbox = gtk_vbox_new (FALSE, 5);
+	gtk_container_add (GTK_CONTAINER (propbox), vbox);
+	gtk_widget_show (vbox);
+	
+	notebook = gtk_notebook_new ();
+	gtk_notebook_set_tab_pos (GTK_NOTEBOOK (notebook), GTK_POS_TOP);
+	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (propbox)->vbox), notebook, TRUE, TRUE, 0);
+	
+	/* Players tab */
 	
 	label = gtk_label_new (_("Players"));
 	gtk_widget_show (label);
-	
+
 	table = gtk_table_new (2, 2, FALSE);
-	gtk_container_border_width (GTK_CONTAINER (table), GNOME_PAD_SMALL);
+	gtk_container_set_border_width (GTK_CONTAINER (table), 6);
 	gtk_widget_show (table);
 	
 	button = gtk_check_button_new_with_label (_("Quick Moves (cut computer delay in half)"));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button),
-			(computer_speed == COMPUTER_MOVE_DELAY / 2));
-	gtk_signal_connect (GTK_OBJECT (button), "toggled", GTK_SIGNAL_FUNC
-			(quick_moves_select), NULL);
+				     (computer_speed == COMPUTER_MOVE_DELAY / 2));
+	g_signal_connect (G_OBJECT (button), "toggled",
+			  G_CALLBACK (quick_moves_select), NULL);
 	gtk_widget_show (button);
 	
 	gtk_table_attach (GTK_TABLE (table), button, 0, 2, 1, 2,
-			GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL,
-			GNOME_PAD_SMALL, GNOME_PAD_SMALL);
+			  GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL,
+			  6, 6);
 	
 	frame = gtk_frame_new (_("Dark"));
 	gtk_widget_show (frame);
 	
 	vbox = gtk_vbox_new (TRUE, 0);
-	gtk_container_border_width (GTK_CONTAINER (vbox), GNOME_PAD_SMALL);
+	gtk_container_set_border_width (GTK_CONTAINER (vbox), 6);
 	gtk_widget_show (vbox);
 	
 	button = gtk_radio_button_new_with_label (NULL, _("Human"));
-	if (black_computer_level == 0)
-		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button),
-				TRUE);
-	gtk_signal_connect (GTK_OBJECT (button), "toggled",
-			GTK_SIGNAL_FUNC (black_computer_level_select),
-			(gpointer) 0);
+	if (black_computer_level == 0) {
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
+	}
+	g_signal_connect (G_OBJECT (button), "toggled",
+			  G_CALLBACK (black_computer_level_select), (gpointer) 0);
 	gtk_widget_show (button);
-	gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
-	button = gtk_radio_button_new_with_label (gtk_radio_button_group
-			(GTK_RADIO_BUTTON (button)), _("Level one"));
-	if (black_computer_level == 1)
-		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button),
-				TRUE);
-	gtk_signal_connect (GTK_OBJECT (button), "toggled",
-			GTK_SIGNAL_FUNC (black_computer_level_select),
-			(gpointer) 1);
-	gtk_widget_show (button);
-	gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
-	button = gtk_radio_button_new_with_label (gtk_radio_button_group
-			(GTK_RADIO_BUTTON (button)), _("Level two"));
-	if (black_computer_level == 2)
-		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button),
-				TRUE);
-	gtk_signal_connect (GTK_OBJECT (button), "toggled",
-			GTK_SIGNAL_FUNC (black_computer_level_select),
-			(gpointer) 2);
-	gtk_widget_show (button);
-	gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
-	button = gtk_radio_button_new_with_label (gtk_radio_button_group
-			(GTK_RADIO_BUTTON (button)), _("Level three"));
-	if (black_computer_level == 3)
-		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button),
-				TRUE);
-	gtk_signal_connect (GTK_OBJECT (button), "toggled",
-			GTK_SIGNAL_FUNC (black_computer_level_select),
-			(gpointer) 3);
-	gtk_widget_show (button);
-	gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
-	
-	gtk_container_add (GTK_CONTAINER (frame), vbox);
 
+	gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
+
+	button = gtk_radio_button_new_with_label (gtk_radio_button_get_group
+		      				 (GTK_RADIO_BUTTON (button)), _("Level one"));
+	if (black_computer_level == 1) {
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
+	}
+	g_signal_connect (G_OBJECT (button), "toggled",
+			  G_CALLBACK (black_computer_level_select), (gpointer) 1);
+	gtk_widget_show (button);
+	
+	gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
+	button = gtk_radio_button_new_with_label (gtk_radio_button_get_group
+						 (GTK_RADIO_BUTTON (button)), _("Level two"));
+	if (black_computer_level == 2) {
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
+	}
+	g_signal_connect (G_OBJECT (button), "toggled",
+			  G_CALLBACK (black_computer_level_select), (gpointer) 2);
+	gtk_widget_show (button);
+
+	gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
+	button = gtk_radio_button_new_with_label (gtk_radio_button_get_group
+			                         (GTK_RADIO_BUTTON (button)), _("Level three"));
+	if (black_computer_level == 3) {
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
+	}
+	g_signal_connect (G_OBJECT (button), "toggled",
+			  G_CALLBACK (black_computer_level_select), (gpointer) 3);
+	gtk_widget_show (button);
+
+	gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
+
+	gtk_container_add (GTK_CONTAINER (frame), vbox);
+	
 	gtk_table_attach (GTK_TABLE (table), frame, 0, 1, 0, 1,
-			GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL,
-			GNOME_PAD_SMALL, GNOME_PAD_SMALL);
+			  GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL,
+			  6, 6);
 	
 	frame = gtk_frame_new (_("Light"));
 	gtk_widget_show (frame);
 	
 	vbox = gtk_vbox_new (TRUE, 0);
-	gtk_container_border_width (GTK_CONTAINER (vbox), GNOME_PAD_SMALL);
+	gtk_container_set_border_width (GTK_CONTAINER (vbox), 6);
 	gtk_widget_show (vbox);
 	
 	button = gtk_radio_button_new_with_label (NULL, _("Human"));
-	if (white_computer_level == 0)
-		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button),
-				TRUE);
-	gtk_signal_connect (GTK_OBJECT (button), "toggled",
-			GTK_SIGNAL_FUNC (white_computer_level_select),
-			(gpointer) 0);
+	if (white_computer_level == 0) {
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
+	}
+	g_signal_connect (G_OBJECT (button), "toggled",
+			  G_CALLBACK (white_computer_level_select), (gpointer) 0);
 	gtk_widget_show (button);
 	gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
-	button = gtk_radio_button_new_with_label (gtk_radio_button_group
-			(GTK_RADIO_BUTTON (button)), _("Level one"));
-	if (white_computer_level == 1)
-		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button),
-				TRUE);
-	gtk_signal_connect (GTK_OBJECT (button), "toggled",
-			GTK_SIGNAL_FUNC (white_computer_level_select),
-			(gpointer) 1);
+	button = gtk_radio_button_new_with_label (gtk_radio_button_get_group
+			                         (GTK_RADIO_BUTTON (button)), _("Level one"));
+	if (white_computer_level == 1) {
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
+	}
+	g_signal_connect (G_OBJECT (button), "toggled",
+			  G_CALLBACK (white_computer_level_select), (gpointer) 1);
 	gtk_widget_show (button);
 	gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
-	button = gtk_radio_button_new_with_label (gtk_radio_button_group
-			(GTK_RADIO_BUTTON (button)), _("Level two"));
-	if (white_computer_level == 2)
-		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button),
-				TRUE);
-	gtk_signal_connect (GTK_OBJECT (button), "toggled",
-			GTK_SIGNAL_FUNC (white_computer_level_select),
-			(gpointer) 2);
+	button = gtk_radio_button_new_with_label (gtk_radio_button_get_group
+			                         (GTK_RADIO_BUTTON (button)), _("Level two"));
+	if (white_computer_level == 2) {
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
+	}
+	g_signal_connect (G_OBJECT (button), "toggled",
+			  G_CALLBACK (white_computer_level_select), (gpointer) 2);
 	gtk_widget_show (button);
 	gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
-	button = gtk_radio_button_new_with_label (gtk_radio_button_group
-			(GTK_RADIO_BUTTON (button)), _("Level three"));
-	if (white_computer_level == 3)
-		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button),
-				TRUE);
-	gtk_signal_connect (GTK_OBJECT (button), "toggled",
-			GTK_SIGNAL_FUNC (white_computer_level_select),
-			(gpointer) 3);
+	button = gtk_radio_button_new_with_label (gtk_radio_button_get_group
+			                         (GTK_RADIO_BUTTON (button)), _("Level three"));
+	if (white_computer_level == 3) {
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
+	}
+	g_signal_connect (G_OBJECT (button), "toggled",
+			  G_CALLBACK (white_computer_level_select), (gpointer) 3);
 	gtk_widget_show (button);
 	gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
 	
-	gtk_container_add (GTK_CONTAINER (frame), vbox);
+	gtk_container_add (GTK_CONTAINER (frame), (vbox));
 
 	gtk_table_attach (GTK_TABLE (table), frame, 1, 2, 0, 1,
-			GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL,
-			GNOME_PAD_SMALL, GNOME_PAD_SMALL);
-	
-	gnome_property_box_append_page (GNOME_PROPERTY_BOX (propbox), table,
-			label);
+			  GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL,
+			  6, 6);
+
+	gtk_notebook_append_page (GTK_NOTEBOOK (notebook), table, label);
+
+	/* Animation tab */
 	
 	label = gtk_label_new (_("Animation"));
 	gtk_widget_show (label);
-	
+
 	table = gtk_table_new (1, 2, FALSE);
-	gtk_container_border_width (GTK_CONTAINER (table), GNOME_PAD_SMALL);
+	gtk_container_set_border_width (GTK_CONTAINER (table), GNOME_PAD_SMALL);
 	gtk_widget_show (table);
 	
-	frame = gtk_frame_new (NULL);
+	frame = gtk_frame_new ("Animation");
 	gtk_widget_show (frame);
 	
 	vbox = gtk_vbox_new (TRUE, 0);
-	gtk_container_border_width (GTK_CONTAINER (vbox), GNOME_PAD_SMALL);
+	gtk_container_set_border_width (GTK_CONTAINER (vbox), GNOME_PAD_SMALL);
 	gtk_widget_show (vbox);
 	
 	button = gtk_radio_button_new_with_label (NULL, _("None"));
-	if (animate == 0)
-		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button),
-				TRUE);
-	gtk_signal_connect (GTK_OBJECT (button), "toggled",
-			GTK_SIGNAL_FUNC (animate_select), (gpointer) 0);
+
+	if (animate == 0) {
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
+	}
+	g_signal_connect (G_OBJECT (button), "toggled",
+			  G_CALLBACK (animate_select), (gpointer) 0);
 	gtk_widget_show (button);
+
 	gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
-	button = gtk_radio_button_new_with_label (gtk_radio_button_group
+	button = gtk_radio_button_new_with_label (gtk_radio_button_get_group
 			(GTK_RADIO_BUTTON (button)), _("Partial"));
-	if (animate == 1)
-		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button),
-				TRUE);
-	gtk_signal_connect (GTK_OBJECT (button), "toggled",
-			GTK_SIGNAL_FUNC (animate_select), (gpointer) 1);
+	if (animate == 1) {
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
+	}
+	g_signal_connect (G_OBJECT (button), "toggled",
+			  G_CALLBACK (animate_select), (gpointer) 1);
 	gtk_widget_show (button);
+
 	gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
-	button = gtk_radio_button_new_with_label (gtk_radio_button_group
-			(GTK_RADIO_BUTTON (button)), _("Complete"));
-	if (animate == 2)
-		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button),
-				TRUE);
-	gtk_signal_connect (GTK_OBJECT (button), "toggled",
-			GTK_SIGNAL_FUNC (animate_select), (gpointer) 2);
+	button = gtk_radio_button_new_with_label (gtk_radio_button_get_group
+			                         (GTK_RADIO_BUTTON (button)), _("Complete"));
+	if (animate == 2) {
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
+	}
+	g_signal_connect (G_OBJECT (button), "toggled",
+			  G_CALLBACK (animate_select), (gpointer) 2);
 	gtk_widget_show (button);
 	gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
 	
 	gtk_container_add (GTK_CONTAINER (frame), vbox);
 
 	gtk_table_attach (GTK_TABLE (table), frame, 0, 1, 0, 1,
-			GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL,
-			GNOME_PAD_SMALL, GNOME_PAD_SMALL);
+			  GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL,
+			  6, 6);
 	
 	vbox = gtk_vbox_new (TRUE, 0);
 	gtk_widget_show (vbox);
 	
-
 	button = gtk_check_button_new_with_label (_("Flip final results"));
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button),
-			t_flip_final);
-	gtk_signal_connect (GTK_OBJECT (button), "toggled",
-			GTK_SIGNAL_FUNC (flip_final_select), NULL);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), t_flip_final);
+	g_signal_connect (G_OBJECT (button), "toggled",
+			  G_CALLBACK (flip_final_select), NULL);
 	gtk_widget_show (button);
 
 	gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
@@ -523,17 +540,11 @@ void show_properties_dialog ()
 	gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 	
 	gtk_table_attach (GTK_TABLE (table), vbox, 1, 2, 0, 1,
-			GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL,
-			GNOME_PAD_SMALL, GNOME_PAD_SMALL);
-	
-	gnome_property_box_append_page (GNOME_PROPERTY_BOX (propbox), table,
-			label);
-	
-	gtk_signal_connect (GTK_OBJECT (propbox), "apply", GTK_SIGNAL_FUNC
-			(apply_cb), NULL);
-	gtk_signal_connect (GTK_OBJECT (propbox), "destroy", GTK_SIGNAL_FUNC
-			(destroy_cb), NULL);
+			  GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL,
+			  6, 6);
+	gtk_notebook_append_page (GTK_NOTEBOOK (notebook), table, label);
 	
+	gtk_widget_show (notebook);
 	gtk_widget_show (propbox);
-	mapped = 1;
-}
+
+}	
