@@ -28,10 +28,12 @@ int find_route(void);
 
 static gint button_press_event (GtkWidget *widget, GdkEvent *event);
 
-void draw_field(GtkWidget *widget);
+void draw_field(GtkWidget *widget, gint redraw);
 
 static gint expose_event (GtkWidget *widget, GdkEventExpose *event, gpointer gp);
 
+void set_inmove(int i);
+
 void init_preview(void);
 
 void draw_preview(void);
