@@ -28,6 +28,7 @@ int
 main(int argc, char *argv[])
 {
 	bindtextdomain(PACKAGE, GNOMELOCALEDIR);
+        bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");	
 	textdomain(PACKAGE);
 	
 	int cmdlineLevel = 0;
@@ -42,7 +43,7 @@ main(int argc, char *argv[])
 
 	gnome_score_init("gnometris");
 
-	gnome_init_with_popt_table("gnometris", TETRIS_VERSION, argc, argv, options, 0, 0);
+        gnome_init ("gnometris", VERSION, argc, argv);
 	gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-gtetris.png");
 
 //	GnomeClient *client= gnome_master_client();
