@@ -12,6 +12,7 @@
 #include <string.h>
 
 #include "minefield.h"
+#include "games-clock.h"
 
 #include "face-worried.xpm"
 #include "face-smile.xpm"
@@ -90,8 +91,9 @@ void top_ten(GtkWidget *widget, gpointer data)
 
 void new_game(GtkWidget *widget, gpointer data)
 {
-        gtk_clock_stop(GTK_CLOCK(clk));
-	gtk_clock_set_seconds(GTK_CLOCK(clk), 0);
+        games_clock_stop(GAMES_CLOCK(clk));
+	games_clock_set_seconds(GAMES_CLOCK(clk), 0);
+
         show_face(pm_smile);
 	gtk_minefield_restart(GTK_MINEFIELD(mfield));
 	gtk_widget_draw(mfield, NULL);
@@ -103,31 +105,35 @@ void new_game(GtkWidget *widget, gpointer data)
 
 void focus_out_cb (GtkWidget *widget, GdkEventFocus *event, gpointer data)
 {
-	if (GTK_CLOCK(clk)->timer_id == -1)
+	if (GAMES_CLOCK(clk)->timer_id == -1)
 		return;
 
 	gtk_widget_hide (mfield);
 	gtk_widget_show (rbutton);
-	gtk_clock_stop(GTK_CLOCK(clk)); 
+
+	games_clock_stop(GAMES_CLOCK(clk)); 
 }
 
-void resume_game_cb (GtkWidget *widget, gpointer data)
+void resume_game_cb (GtkButton *widget, gpointer data)
 {
 	gtk_widget_hide (rbutton);
 	gtk_widget_show (mfield);
-	gtk_clock_start(GTK_CLOCK(clk));
+
+	games_clock_start(GAMES_CLOCK(clk));
 }
 
 void marks_changed(GtkWidget *widget, gpointer data)
 {
         set_flabel(GTK_MINEFIELD(widget));
-	gtk_clock_start(GTK_CLOCK(clk));
+
+	games_clock_start(GAMES_CLOCK(clk));
 }
 
 void lose_game(GtkWidget *widget, gpointer data)
 {
         show_face(pm_sad);
-        gtk_clock_stop(GTK_CLOCK(clk));
+
+        games_clock_stop(GAMES_CLOCK(clk));
 }
 
 void win_game(GtkWidget *widget, gpointer data)
@@ -136,19 +142,20 @@ void win_game(GtkWidget *widget, gpointer data)
         int pos;
         gchar buf[64];
 
-        gtk_clock_stop(GTK_CLOCK(clk));
+
+        games_clock_stop(GAMES_CLOCK(clk));
+
         show_face(pm_win);
 
 	if(fsize<3) {
-	    score = (gfloat) (GTK_CLOCK(clk)->stopped / 60) + 
-		    (gfloat) (GTK_CLOCK(clk)->stopped % 60) / 100;
+	    score = (gfloat) (GAMES_CLOCK(clk)->stopped / 60) + 
+		    (gfloat) (GAMES_CLOCK(clk)->stopped % 60) / 100;
 
             strncpy(buf, fsize2names[fsize], sizeof(buf));
 	    pos = gnome_score_log(score, buf, FALSE);
-
 	} else {
 	    score = ((nmines * 100) / (xsize * ysize)) /
-		    (gfloat) (GTK_CLOCK(clk)->stopped); 
+		    (gfloat) (GAMES_CLOCK(clk)->stopped); 
 
             strncpy(buf, fsize2names[fsize], sizeof(buf));
 	    pos = gnome_score_log(score, buf, TRUE);
@@ -159,7 +166,8 @@ void win_game(GtkWidget *widget, gpointer data)
 void look_cell(GtkWidget *widget, gpointer data)
 {
         show_face(pm_worried);
-        gtk_clock_start(GTK_CLOCK(clk));
+
+        games_clock_start(GAMES_CLOCK(clk));
 }
 
 void unlook_cell(GtkWidget *widget, gpointer data)
@@ -214,7 +222,11 @@ about(GtkWidget *widget, gpointer data)
 		N_("Score: HoraPe"),
 		NULL
 	};
-
+	const gchar *documenters[] = {
+                NULL
+        };
+	const gchar *translator_credits = _("");
+	
 	if (about) {
 		gdk_window_raise (about->window);
 		gdk_window_show (about->window);
@@ -230,8 +242,10 @@ about(GtkWidget *widget, gpointer data)
 
         about = gnome_about_new (_("Gnome Mines"), VERSION,
 				 _("(C) 1997-1999 the Free Software Foundation"),
-				 (const char **)authors,
 				 _("Minesweeper clone"),
+				 (const char **)authors,
+				 (const char **)documenters,
+                                 (const char *)translator_credits,
 				 NULL);
 	gtk_signal_connect (GTK_OBJECT (about), "destroy", GTK_SIGNAL_FUNC
 			(gtk_widget_destroyed), &about);
@@ -256,10 +270,11 @@ void size_radio_callback(GtkWidget *widget, gpointer data)
 
 static void help_cb (GtkWidget * widget, gpointer data)
 {
-
+#if 0
   GnomeHelpMenuEntry help_entry = { "gnome-mines", "menubar.html" };
 
   gnome_help_display (NULL, &help_entry);
+#endif
 }
 
 static void apply_cb (GtkWidget *widget, gint pagenum, gpointer data)
@@ -348,7 +363,7 @@ void preferences_callback (GtkWidget *widget, gpointer data)
         gtk_widget_show(button);
 
 	button = gtk_radio_button_new_with_label
-		(gtk_radio_button_group (GTK_RADIO_BUTTON(button)),
+		(gtk_radio_button_get_group (GTK_RADIO_BUTTON(button)),
 		 _("Medium"));
 	if (fsize == 1)
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button),
@@ -359,7 +374,7 @@ void preferences_callback (GtkWidget *widget, gpointer data)
         gtk_widget_show (button);
 
 	button = gtk_radio_button_new_with_label
-		(gtk_radio_button_group (GTK_RADIO_BUTTON (button)),
+		(gtk_radio_button_get_group (GTK_RADIO_BUTTON (button)),
 		 _("Biiiig"));
 	if (fsize == 2)
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button),
@@ -370,7 +385,7 @@ void preferences_callback (GtkWidget *widget, gpointer data)
         gtk_widget_show(button);
 	
 	button = gtk_radio_button_new_with_label
-		(gtk_radio_button_group(GTK_RADIO_BUTTON(button)),
+		(gtk_radio_button_get_group(GTK_RADIO_BUTTON(button)),
 		 _("Custom"));
 	if (fsize == 3)
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button),
@@ -457,14 +472,16 @@ void preferences_callback (GtkWidget *widget, gpointer data)
 
         adj = gtk_adjustment_new(minesize, 2, 99, 1, 5, 10);
 	sentry = gtk_spin_button_new(GTK_ADJUSTMENT(adj), 10, 0);
+#if 0	
         gtk_spin_button_set_update_policy(GTK_SPIN_BUTTON(sentry),
 					  GTK_UPDATE_ALWAYS
-#ifndef HAVE_GTK_SPIN_BUTTON_SET_SNAP_TO_TICKS
+ ifndef HAVE_GTK_SPIN_BUTTON_SET_SNAP_TO_TICKS
 					  | GTK_UPDATE_SNAP_TO_TICKS
-#endif
+ endif
 					  );
-#ifdef HAVE_GTK_SPIN_BUTTON_SET_SNAP_TO_TICKS
+ ifdef HAVE_GTK_SPIN_BUTTON_SET_SNAP_TO_TICKS
 	gtk_spin_button_set_snap_to_ticks(GTK_SPIN_BUTTON(sentry), 1);
+ endif
 #endif
 	gtk_signal_connect (GTK_OBJECT (adj), "value_changed", GTK_SIGNAL_FUNC
 			(prop_box_changed_callback), NULL);
@@ -600,8 +617,9 @@ main (int argc, char *argv[])
 
 	gnome_score_init("gnomine");
 
-	bindtextdomain (PACKAGE, GNOMELOCALEDIR);
-	textdomain (PACKAGE);
+	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+	textdomain (GETTEXT_PACKAGE);
 
         gnome_init_with_popt_table("gnomine", VERSION, argc, argv,
 				   options, 0, NULL);
@@ -630,7 +648,6 @@ main (int argc, char *argv[])
 	  fsize  = gnome_config_get_int("/gnomine/geometry/mode=0");
 
 	verify_ranges ();
-        gdk_imlib_init ();
 
 #ifdef ENABLE_NLS 
 #define ELEMENTS(x) (sizeof(x) / sizeof(x[0])) 
@@ -647,6 +664,7 @@ main (int argc, char *argv[])
 
         window = gnome_app_new("gnomine", _("Gnome Mines"));
 	gnome_app_create_menus(GNOME_APP(window), mainmenu);
+	gtk_window_set_policy(GTK_WINDOW (window), TRUE, TRUE, TRUE);
 
 	appbar = GNOME_APPBAR (gnome_appbar_new(FALSE, FALSE, FALSE));
 	gnome_app_set_statusbar(GNOME_APP (window), GTK_WIDGET (appbar));
@@ -700,8 +718,8 @@ main (int argc, char *argv[])
 			  0, 0);
         gtk_widget_show (align);
   
-	gtk_widget_push_visual (gdk_imlib_get_visual ());
-	gtk_widget_push_colormap (gdk_imlib_get_colormap ());
+	gtk_widget_push_visual (gdk_rgb_get_visual ());
+	gtk_widget_push_colormap (gdk_rgb_get_colormap ());
 	gtk_widget_pop_colormap ();
 	gtk_widget_pop_visual ();
 
@@ -711,7 +729,8 @@ main (int argc, char *argv[])
 	gtk_box_pack_start(GTK_BOX(box), mfield, FALSE, FALSE, 0);
 
 	rbutton = gtk_button_new_with_label ("Press to resume");
-	gtk_signal_connect (GTK_OBJECT(rbutton), "released", resume_game_cb, NULL);
+	gtk_signal_connect (GTK_OBJECT(rbutton), "released", 
+			    GTK_SIGNAL_FUNC (resume_game_cb), NULL);
 	gtk_box_pack_start(GTK_BOX(box), rbutton, TRUE, FALSE, 0);
 	gtk_widget_show (box);
 
@@ -748,19 +767,17 @@ main (int argc, char *argv[])
 			 2, 3, 0, 1, 0, 0, 3, 3);
 	gtk_widget_show(label);
 
-        clk = gtk_clock_new(GTK_CLOCK_INCREASING);
+        clk = games_clock_new();
 	gtk_table_attach(GTK_TABLE(status_table), clk,
 		3, 4, 0, 1, 0, 0, 3 ,3);
 	gtk_widget_show(clk);
-	
+
         gtk_widget_show(status_table);
 	
 	gtk_widget_show(all_boxes);
 
 	new_game(mfield, NULL);
 
-        /* gtk_window_set_policy(GTK_WINDOW(window), FALSE, FALSE, TRUE); */
-
         gtk_widget_show(window);
 
         gtk_main();
