@@ -1,7 +1,7 @@
 
 #include <time.h>
 #include <gtk/gtk.h>
-#include <gdk_imlib.h>
+#include <gdk-pixbuf/gdk-pixbuf.h>
 #include <gnome.h>
 #include "minefield.h"
 #include "flag.xpm"
@@ -58,17 +58,16 @@ static inline gint cell_idx(GtkMineField *mfield, guint x, guint y)
 	return -1;
 }
 
-static void _setup_sign (sign *signp, char **data, guint minesize)
+static void _setup_sign (sign *signp, const char **data, guint minesize)
 {
-	GdkImlibImage *image;
+	GdkPixbuf *image;
 
-        image = gdk_imlib_create_image_from_xpm_data(data);
-        gdk_imlib_render (image,
-			  5 * (minesize - 2) / 8,
-			  5 * (minesize - 2) / 8);
-        signp->pixmap = gdk_imlib_move_image (image);
-        signp->mask = gdk_imlib_move_mask (image);
-	gdk_imlib_destroy_image (image);
+	image = gdk_pixbuf_new_from_xpm_data ( (const char **) data);
+
+	gdk_pixbuf_render_pixmap_and_mask (image, &signp->pixmap,
+					   &signp->mask, 127);
+
+	gdk_pixbuf_unref (image);
         gdk_window_get_size(signp->pixmap, &(signp->width), &(signp->height));
 }
 
@@ -116,9 +115,6 @@ static void gtk_minefield_realize(GtkWidget *widget)
         gtk_style_set_background(widget->style, widget->window, GTK_STATE_ACTIVE);
 
         gtk_minefield_setup_signs(widget);
-
-        mfield->cc = gdk_color_context_new (gtk_widget_get_visual (widget),
-					    gtk_widget_get_colormap (widget));
 }
 
 static void gtk_minefield_unrealize (GtkWidget *widget)
@@ -130,9 +126,6 @@ static void gtk_minefield_unrealize (GtkWidget *widget)
 
 	mfield = GTK_MINEFIELD (widget);
 
-	gdk_color_context_free (mfield->cc);
-	mfield->cc = NULL;
-
 	if (GTK_WIDGET_CLASS (parent_class)->unrealize)
 		(* GTK_WIDGET_CLASS (parent_class)->unrealize) (widget);
 }
@@ -335,8 +328,9 @@ static gint gtk_minefield_expose(GtkWidget *widget,
 		mfield->font = gdk_font_load(fontname);
 	  
 	            /* The font used to be "-misc-fixed-bold-r-normal--13-*-*-*-*-*-*" */
-	  
+#if 0	  
                 if (!mfield->font) mfield->font = widget->style->font;
+#endif
 		for (i=0; i<9; i++) {
 			mfield->numstr[i].text[0] = i+'0';
 			mfield->numstr[i].text[1] = '\0';
@@ -352,12 +346,9 @@ static gint gtk_minefield_expose(GtkWidget *widget,
 			color.pixel = 0; /* required! */
 
 			n = 0;
-			gdk_color_context_get_pixels (mfield->cc,
-						      &color.red, &color.green, &color.blue,
-						      1,
-						      &color.pixel,
-						      &n);
-
+			
+			gdk_rgb_find_color (gtk_widget_get_colormap (widget), &color);
+			
 			gdk_gc_set_foreground(mfield->numstr[i].gc, &color);
 		}
 	}
@@ -724,7 +715,7 @@ static void gtk_minefield_class_init (GtkMineFieldClass *class)
 	minefield_signals[MARKS_CHANGED_SIGNAL] =
 		gtk_signal_new("marks_changed",
 			       GTK_RUN_FIRST,
-			       object_class->type,
+			       GTK_CLASS_TYPE (object_class),
 			       GTK_SIGNAL_OFFSET(GtkMineFieldClass, marks_changed),
 			       gtk_signal_default_marshaller,
 			       GTK_TYPE_NONE,
@@ -732,7 +723,7 @@ static void gtk_minefield_class_init (GtkMineFieldClass *class)
 	minefield_signals[EXPLODE_SIGNAL] =
 		gtk_signal_new("explode",
 			       GTK_RUN_FIRST,
-			       object_class->type,
+			       GTK_CLASS_TYPE (object_class),
 			       GTK_SIGNAL_OFFSET(GtkMineFieldClass, explode),
 			       gtk_signal_default_marshaller,
 			       GTK_TYPE_NONE,
@@ -740,7 +731,7 @@ static void gtk_minefield_class_init (GtkMineFieldClass *class)
 	minefield_signals[LOOK_SIGNAL] =
 		gtk_signal_new("look",
 			       GTK_RUN_FIRST,
-			       object_class->type,
+			       GTK_CLASS_TYPE (object_class),
 			       GTK_SIGNAL_OFFSET(GtkMineFieldClass, look),
 			       gtk_signal_default_marshaller,
 			       GTK_TYPE_NONE,
@@ -748,7 +739,7 @@ static void gtk_minefield_class_init (GtkMineFieldClass *class)
 	minefield_signals[UNLOOK_SIGNAL] =
 		gtk_signal_new("unlook",
 			       GTK_RUN_FIRST,
-			       object_class->type,
+			       GTK_CLASS_TYPE (object_class),
 			       GTK_SIGNAL_OFFSET(GtkMineFieldClass, unlook),
 			       gtk_signal_default_marshaller,
 			       GTK_TYPE_NONE,
@@ -756,23 +747,25 @@ static void gtk_minefield_class_init (GtkMineFieldClass *class)
 	minefield_signals[WIN_SIGNAL] =
 		gtk_signal_new("win",
 			       GTK_RUN_FIRST,
-			       object_class->type,
+			       GTK_CLASS_TYPE (object_class),
 			       GTK_SIGNAL_OFFSET(GtkMineFieldClass, win),
 			       gtk_signal_default_marshaller,
 			       GTK_TYPE_NONE,
 			       0);
-
+#if 0
 	gtk_object_class_add_signals(object_class, minefield_signals, LAST_SIGNAL);
+#endif
 }
 
 static void gtk_minefield_init (GtkMineField *mfield)
 {
 #ifndef GTK_HAVE_FEATURES_1_1_4
+  #if 0
         GTK_WIDGET_SET_FLAGS (mfield, GTK_BASIC);
+  #endif
 #endif
         mfield->xsize = 0;
         mfield->ysize = 0;
-	mfield->cc = NULL;
 
         GTK_WIDGET (mfield)->requisition.width = mfield->minesize;
         GTK_WIDGET (mfield)->requisition.height = mfield->minesize;
@@ -817,8 +810,9 @@ guint gtk_minefield_get_type ()
                                 sizeof (GtkMineFieldClass),
                                 (GtkClassInitFunc) gtk_minefield_class_init,
                                 (GtkObjectInitFunc) gtk_minefield_init,
-                                (GtkArgSetFunc) NULL,
-                                (GtkArgGetFunc) NULL,
+                                /* reserved_1 */ NULL,
+        			/* reserved_2 */ NULL,
+        			(GtkClassInitFunc) NULL,
                         };
                         
                         minefield_type = gtk_type_unique (gtk_widget_get_type (), &minefield_info);
