@@ -21,6 +21,7 @@
 #include <config.h>
 #include <gnome.h>
 #include <libgnomeui/gnome-window-icon.h>
+#include <gdk-pixbuf/gdk-pixbuf.h>
 #include "pieces.h"
 
 #define APPNAME "gnotski"
@@ -480,8 +481,9 @@ int main (int argc, char **argv){
   GnomeClient *client;
 
   gnome_score_init(APPNAME);
-  bindtextdomain(PACKAGE, GNOMELOCALEDIR);
-  textdomain(PACKAGE);
+  bindtextdomain(GETTEXT_PACKAGE, GNOMELOCALEDIR);
+  bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+  textdomain(GETTEXT_PACKAGE);
    
   gnome_init_with_popt_table(APPNAME, VERSION, argc, argv, options, 0, NULL);
   gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnotski-icon.png");
@@ -636,8 +638,8 @@ gint configure_space(GtkWidget *widget, GdkEventConfigure *event){
 }
 
 void create_space(){
-  gtk_widget_push_visual(gdk_imlib_get_visual());
-  gtk_widget_push_colormap(gdk_imlib_get_colormap());
+  gtk_widget_push_visual(gdk_rgb_get_visual ());
+  gtk_widget_push_colormap(gdk_rgb_get_cmap());
   space = gtk_drawing_area_new();
   gtk_widget_pop_colormap();
   gtk_widget_pop_visual();
@@ -685,21 +687,17 @@ void message(gchar *message){
 
 void load_image(){
   char *fname;
-  GdkImlibImage *image;
-  GdkVisual *visual;
+  GdkPixbuf *image;
 
   fname = gnome_unconditional_pixmap_file("gnotski.png");
   if(!g_file_exists(fname)) {
     g_print(_("Could not find \'%s\' pixmap file\n"), fname); exit(1);
   }
-  image = gdk_imlib_load_image(fname);
-  visual = gdk_imlib_get_visual();
-  if(visual->type != GDK_VISUAL_TRUE_COLOR) {
-    gdk_imlib_set_render_type(RT_PLAIN_PALETTE);
-  }
-  gdk_imlib_render(image, image->rgb_width, image->rgb_height);
-  tiles_pixmap = gdk_imlib_move_image(image);
-  gdk_imlib_destroy_image(image);
+  image = gdk_pixbuf_new_from_file(fname, NULL);
+
+  gdk_pixbuf_render_pixmap_and_mask (image, &tiles_pixmap, NULL, 127);
+
+  gdk_pixbuf_unref(image);
   g_free(fname);
 }
 
@@ -971,12 +969,20 @@ void about_cb(GtkWidget *widget, gpointer data){
   GtkWidget *about;
   
   const gchar *authors[] = { "Lars Rydlinge", NULL };
+  gchar *documenters[] = {
+                          NULL
+                         };
+  /* Translator credits */
+  gchar *translator_credits = _("");
+  
   about = gnome_about_new(_(APPNAME_LONG), 
                           VERSION, 
                           "(C) 1999 Lars Rydlinge",
-			  (const char **)authors, 
 			  _("Klotski clone\n" \
 			    "(Comments to: Lars.Rydlinge@HIG.SE)"), 
-                          NULL);
+                          (const char **)authors, 
+                          (const char **)documenters,
+                          (const char *)translator_credits,
+			  NULL);
   gtk_widget_show(about);
 }
