@@ -67,8 +67,18 @@ void UI::make_mainwin() {
 	gtk_widget_ensure_style(field);
 	style = field->style;
 	colormap = style->colormap;
-	white.red = style->white.red; white.green = style->white.green;
-	white.blue = style->white.blue; white.pixel = style->white.pixel;
+
+	/* try to alloc color */
+	if (colormap)
+		gdk_color_white(colormap, &white);
+	else if (gdk_color_white(gdk_colormap_get_system(), &white)) {
+		style = gtk_style_copy(gtk_widget_get_style(GTK_WIDGET(field)));
+
+		/* set new style */
+		style->bg[GTK_STATE_NORMAL] = white;
+		gtk_widget_set_style(GTK_WIDGET(field), style);
+	}
+
 	black.red = style->black.red; black.green = style->black.green;
 	black.blue = style->black.blue; black.pixel = style->black.pixel;
 
@@ -104,23 +114,23 @@ void UI::make_windows() {
 
 	gdk_window_set_icon(toplevel->window, NULL, icon.pix, NULL);
 	/* XXXXX */
-	newgamebox = CreateDialog ("New Game", OK|CANCEL, NULL,
+	newgamebox = CreateDialog (_("New Game"), OK|CANCEL, NULL,
 		newgamestr, (char *)NULL, GTK_SIGNAL_FUNC(new_game_cb));
-	pausebox = CreateDialog ("Pause Game", OK, icon.pix,
-		pausestr, "Continue", NULL);
-	quitbox = CreateDialog ("Quit", OK|CANCEL, NULL,
+	pausebox = CreateDialog (_("Pause Game"), OK, icon.pix,
+		pausestr, _("Continue"), NULL);
+	quitbox = CreateDialog (_("Quit"), OK|CANCEL, NULL,
 		quitstr, (char *)NULL, GTK_SIGNAL_FUNC(quit_game_cb));
-	warpbox = CreateEnterText ("Warp To Level", warpstr,
+	warpbox = CreateEnterText (_("Warp To Level"), warpstr,
 		GTK_SIGNAL_FUNC(warp_apply));
 	about.load("about");
 
-	aboutbox = CreatePixmapBox("About", about.pix,
-		"Ported to GNOME by James Henstridge <james@daa.com.au>");
-	rulesbox = CreatePixmapBox("Rules", NULL, rulesstr);
-	storybox = CreatePixmapBox("Story", NULL, storystr);
+	aboutbox = CreatePixmapBox(_("About"), about.pix,
+		_("Ported to GNOME by James Henstridge <james@daa.com.au>"));
+	rulesbox = CreatePixmapBox(_("Rules"), NULL, rulesstr);
+	storybox = CreatePixmapBox(_("Story"), NULL, storystr);
 
-	scorebox = CreateDialog ("Score", OK, NULL, "", (char *)NULL, NULL);
-	endgamebox = CreateDialog ("Endgame", OK, NULL,
+	scorebox = CreateDialog (_("Score"), OK, NULL, "", (char *)NULL, NULL);
+	endgamebox = CreateDialog (_("Endgame"), OK, NULL,
 		endgamestr, "Nuts!", NULL);
 }
 
@@ -174,7 +184,7 @@ void UI::graph_init() {
 
 	gtk_widget_ensure_style(field);
 	gtk_widget_realize(field);
-	font = field->style->font;
+
 	offscreen = gdk_pixmap_new(field->window, game.scrwidth, game.scrheight,
 				   -1);
 }
@@ -205,7 +215,16 @@ void UI::draw_line(int x1, int y1, int x2, int y2) {
 }
 
 void UI::draw_str(char *str, int x, int y) {
-        gdk_draw_string(offscreen, font, stdgc, x,y, str);
+	PangoLayout *layout = gtk_widget_create_pango_layout (field, str);
+	int h;
+
+	pango_layout_get_pixel_size (layout, NULL, &h);
+
+	y -= h;
+
+	gdk_draw_layout (offscreen, stdgc, x, y, layout);
+
+	g_object_unref (layout);
 }
 
 
